/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.cat.stat.handler;

import java.io.File;
import java.io.IOException;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.xml.sax.SAXException;

import benten.cat.glossary.core.BentenGlossaryEngine;
import benten.cat.stat.CatStatPlugin;
import benten.cat.stat.model.GlossaryHitRateModel;
import benten.core.model.BentenXliff;
import benten.core.text.Strings;
import blanco.xliff.valueobject.BlancoXliffTransUnit;

/**
 * 用語対訳集ヒット率取得ハンドラーです。
 * 
 * ★基本設計「翻訳ワークフロー支援機能: 翻訳統計取得機能: 用語対訳集ヒット率ビュー」に対応します。
 */
public class ShowGlossaryHitRateHandler extends AbstractStatHandler<GlossaryHitRateModel> {

	private static final Set<String> cache = new HashSet<String>();

	@Override
	protected GlossaryHitRateModel processFile(File file) throws IOException, SAXException {
		final GlossaryHitRateModel model = new GlossaryHitRateModel();
		model.setFile(file);
		final BentenXliff xliff = BentenXliff.loadInstance(file);
		final List<BlancoXliffTransUnit> unitList = xliff.getAllTransUnitList();
		for (final BlancoXliffTransUnit unit : unitList) {
			final String source = unit.getSource();
			if (source != null) {
				setHitRate(source, model);
			}
		}
		return model;
	}

	protected void setHitRate(String source, GlossaryHitRateModel model) {
		final BentenGlossaryEngine glossaryEngine = CatStatPlugin.getGlossaryEngine();
		final String[] words = Strings.splitByWhitespace(source);
		int hit = 0;
		for (final String word : words) {
			if (cache.contains(word)) {
				hit++;
			} else {
				if (glossaryEngine.search(word).size() > 0) {
					hit++;
					cache.add(word);
				}
			}
		}
		final int rate = 100 * hit / words.length;
		if (rate >= 75) {
			model.setHit75(model.getHit75() + 1);
		} else if (rate >= 50) {
			model.setHit50(model.getHit50() + 1);
		} else if (rate >= 25) {
			model.setHit25(model.getHit25() + 1);
		} else {
			model.setHitUnder25(model.getHitUnder25() + 1);
		}
	}
}
